@@ -1,5 +1,17 @@
-#!/usr/bin/python
 # -*- coding: utf-8 -*-
+#  Copyright 2011 Takeshi KOMIYA
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 from elements import *
 import diagparser
@@ -61,12 +73,6 @@ class DiagramLayoutManager:
         self.layout_nodes()
         self.set_network_size()
 
-        # Slide nodes to bottom-side
-        for node in self.diagram.nodes:
-            node.xy = XY(node.xy.x + 1, node.xy.y + 1)
-        for network in self.diagram.networks:
-            network.xy = XY(network.xy.x + 1, network.xy.y + 1)
-
     def sort_networks(self):
         def compare(a, b):
             n1 = [n for n in nodes  if a in n.networks]
