@@ -1,5 +1,17 @@
-#!bin/py
 # -*- coding: utf-8 -*-
+#  Copyright 2011 Takeshi KOMIYA
+#
+#  Licensed under the Apache License, Version 2.0 (the "License");
+#  you may not use this file except in compliance with the License.
+#  You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+#  Unless required by applicable law or agreed to in writing, software
+#  distributed under the License is distributed on an "AS IS" BASIS,
+#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#  See the License for the specific language governing permissions and
+#  limitations under the License.
 
 import re
 import sys
@@ -16,22 +28,6 @@ class Diagram(blockdiag.elements.Diagram):
         self.span_height = 120
         self.networks = []
 
-    def set_attributes(self, attrs):
-        for attr in attrs:
-            value = unquote(attr.value)
-
-            if attr.name == 'default_shape':
-                try:
-                    noderenderer.get(value)
-                    DiagramNode.set_default_shape(value)
-                except:
-                    msg = "WARNING: unknown node shape: %s\n" % value
-                    raise RuntimeError(msg)
-            elif attr.name == 'shape_namespace':
-                noderenderer.set_default_namespace(value)
-            else:
-                self.set_attribute(attr)
-
     def fixiate(self):
         if len(self.nodes) + len(self.networks) > 0:
             nodes = self.nodes + self.networks
@@ -59,3 +55,15 @@ class NodeGroup(blockdiag.elements.NodeGroup):
         super(NodeGroup, self).__init__(id)
 
         self.address = None
+
+    @property
+    def display_label(self):
+        if self.label:
+            if self.address:
+                label = "%s\n%s" % (self.label, self.address)
+            else:
+                label = self.label
+        else:
+            label = self.address
+
+        return label
